@@ -263,3 +263,18 @@ class EnvVars(BaseModel):
 
 class ExportAssistantPayload(BaseModel):
     env_vars: Optional[EnvVars] = None
+
+
+class AssistantEvaluationRequest(BaseModel):
+    """Model for assistant evaluation request."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    dataset_id: str = Field(description="ID of the dataset to use for evaluation")
+    experiment_name: str = Field(description="Name of the evaluation experiment")
+    system_prompt: Optional[str] = Field(
+        default=None, description="System prompt to use for evaluation"
+    )
+    llm_model: Optional[str] = Field(
+        default=None, description="LLM model to use for evaluation"
+    )
